#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lrucache
version:              1.2.0.1
visibility:           public
id:                   lrucache-1.2.0.1-1IltEDNuOkv2vD1LGu3d2T
key:                  lrucache-1.2.0.1-1IltEDNuOkv2vD1LGu3d2T
license:              BSD-3-Clause
copyright:            Carl Howells, 2010-2015
maintainer:           chowells79@gmail.com
author:               Carl Howells
stability:            Experimental
homepage:             http://github.com/chowells79/lrucache
synopsis:             a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".

    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.

category:             Data
abi:                  7a10b6e14f26c1eeec935097c2480b29
exposed:              True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal

import-dirs:          /usr/lib/ghc-8.10.5/site-local/lrucache-1.2.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/lrucache-1.2.0.1
hs-libraries:         HSlrucache-1.2.0.1-1IltEDNuOkv2vD1LGu3d2T
depends:
    base-4.14.2.0 containers-0.6.4.1
    contravariant-1.5.5-VKJo98a2679MZilCyOyb5

haddock-interfaces:   /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html:         /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

